% Plane stress - plane strain using constant strain triangular elements (CST)
%
% Input data from Excel spreadsheet "CST_input_data.xlsx"
clear all
clc
format shorteng

filename = 'CSTa_4_elements.xlsx';

xy = xlsread(filename,'Coordinates','B3:C1000');
C  = xlsread(filename,'Connectivity','B3:D1000');
F  = xlsread(filename,'Forces','B2:B1000');
v  = xlsread(filename,'Poisson','B2:B1000');
%t  = xlsread(filename,'Thickness','B2:B1000');
E  = xlsread(filename,'Elasticity','B3:B1000');
boundary = xlsread(filename,'Boundary','B2:B1000');

%TYPE = xlsread(filename,'Plane stress-strain','A2:A2');

NumEle = size(C,1);
NumNod = max(max(C));
NumDof = 2*NumNod;
Nodes  = 3;
xy_order = [1 2 3];

K = Stiffness_axisymmetric(E,C,xy,v);

loc     = find(boundary==0);
locFIX  = find(boundary==1);
DofFree = length(loc);

Kelim = zeros(DofFree);
Felim = zeros(DofFree,1);

for i = 1:DofFree
    for j=1:DofFree
        Kelim(i,j) = K(loc(i),loc(j));
    end
end

for i = 1:DofFree
    Felim(i,1) = F(loc(i));
end

d = Kelim\Felim;

displacement = zeros(NumDof,1);
displacement(loc,1) = d;


% % Element stresses
Se = Stress_axisymmetric(E,C,xy,v,displacement);

% Write displacements and stress to Excel file
write_results_axisym(filename,NumNod,Nodes,NumEle,C,xy_order,displacement,Se)

% Plot displacements
plot_results_axisym(xy,NumEle,Nodes,C,xy_order,displacement,Se);

