function [ K ] = Stiffness_axisymmetric( E,C,s,v )
% Stresses for each element [Se]=(AE/L)[B'][B]
%   [B] is the matrix that relates strains to displacments
%   E is modulus of elastcity of the element
%   L is the length of the element
%   A is the area of the element
%   v is Poisson's ratio

NumEle = size(C,1);
NumDof = 2*max(max(C));

K = zeros(NumDof);
%A = zeros(NumEle,1);

for iele = 1:NumEle
    
    D = E(iele)/(1+v)/(1-2*v)*[1-v   v    v    0;
                                v   1-v   v    0;
                                v    v   1-v   0;
                                0    0    0  .5-v];  % stress/strain
    
    S1 = s(C(iele,1),:);
    S2 = s(C(iele,2),:);
    S3 = s(C(iele,3),:);
    
    X13=S1(1)-S3(1);
    X21=S2(1)-S1(1);
    X23=S2(1)-S3(1);
    
    Y13=S1(2)-S3(2);
    Y12=S1(2)-S2(2);
    Y23=S2(2)-S3(2);
    
    Z1 = S2(1)*S3(2) -  S2(2)*S3(1);
    Z2 = S3(1)*S1(2) -  S3(2)*S1(1);
    Z3 = S1(1)*S2(2) -  S2(1)*S1(2);
    
    rbar = (S1(1)+S2(1)+S3(1))/3;
    zbar = (S1(2)+S2(2)+S3(2))/3;
    
    Z23 = Z1/rbar + Y23 - X23*zbar/rbar;
    Z13 = Z2/rbar - Y13 + X13*zbar/rbar;
    Z12 = Z3/rbar + Y12 + X21*zbar/rbar;
    
    DetJ = det([X13 Y13;
                X23 Y23]);
    A = abs(DetJ)/2;
    
    B =(1/DetJ)*[ Y23    0 -Y13    0  Y12   0 ;
                    0 -X23    0  X13    0 X21 ;
                  Z23    0  Z13    0  Z12   0 ;
                 -X23  Y23  X13 -Y13  X21 Y12 ];
          
    Ke = (2*pi*rbar*A).*(B')*D*(B);
     
    Ktemp = zeros(NumDof);
    
    for i = 1:6
        for j = 1:6
            
            ii = mod(i,2);
            jj = mod(j,2);
            
            if (ii == 0)
                index1=2*C(iele,round(i/2));
            else
                index1=2*C(iele,round(i/2))-1;
            end
            if (jj == 0)
                index2=2*C(iele,round(j/2));
            else
                index2=2*C(iele,round(j/2))-1;
            end
 
            Ktemp(index1,index2)= Ke(i,j);
            
        end
    end
    
    K = Ktemp + K;
     
end

