function [ Se ] = Stress_axisymmetric( E,C,s,v,displacement )
% Siffness matrix in global coordinates [Ke]=(AE/L)[B'][B]
%   [B] is the matrix that relates strains to displacments
%   E is modulus of elastcity of the element
%   L is the length of the element
%   A is the area of the element
%   v is Poisson's ratio
%   d are the nodal dispalcements

NumEle = size(C,1);
%NumDof = 2*max(max(C));

Se = zeros(NumEle,4);

for iele = 1:NumEle
    
    D = E(iele)/(1+v)/(1-2*v)*[1-v   v    v    0;
                                v   1-v   v    0;
                                v    v   1-v   0;
                                0    0    0  .5-v];  % stress/strain
    
    S1 = s(C(iele,1),:);
    S2 = s(C(iele,2),:);
    S3 = s(C(iele,3),:);
    
    X13=S1(1)-S3(1);
    X21=S2(1)-S1(1);
    X23=S2(1)-S3(1);
    
    Y13=S1(2)-S3(2);
    Y12=S1(2)-S2(2);
    Y23=S2(2)-S3(2);
    
    Z1 = S2(1)*S3(2) -  S2(2)*S3(1);
    Z2 = S3(1)*S1(2) -  S3(2)*S1(1);
    Z3 = S1(1)*S2(2) -  S2(1)*S1(2);
    
    rbar = (S1(1)+S2(1)+S3(1))/3;
    zbar = (S1(2)+S2(2)+S3(2))/3;
    
    Z23 = Z1/rbar + Y23 - X23*zbar/rbar;
    Z13 = Z2/rbar - Y13 + X13*zbar/rbar;
    Z12 = Z3/rbar + Y12 + X21*zbar/rbar;
    
    DetJ = det([X13 Y13;
                X23 Y23]);
    
    B =(1/DetJ)*[ Y23    0 -Y13    0  Y12   0 ;
                    0 -X23    0  X13    0 X21 ;
                  Z23    0  Z13    0  Z12   0 ;
                 -X23  Y23  X13 -Y13  X21 Y12 ];
   
   dtemp(1:6,1) = 0;
             
   for i = 1:6  
       
           if i==1 
               index1=2*C(iele,1)-1;
           elseif i==2
               index1=2*C(iele,1);
           elseif i==3
               index1=2*C(iele,2)-1;
           elseif i==4
               index1=2*C(iele,2);
           elseif i==5
               index1=2*C(iele,3)-1;
           elseif i==6
               index1=2*C(iele,3);
           end
           
           dtemp(i,1)= displacement(index1,1);
            
    end
    
    Se(iele,:) = D*B*dtemp;
     
end

